@@ -435,21 +435,50 @@ _SEQDB = {
     '> ESC +H'           : 'designate G3 charset: Swedish',
     '> ESC +7'           : 'designate G3 charset: Swedish',
     '> ESC +='           : 'designate G3 charset: Swiss',
-    '> ESC P<ST>'        : 'DCS',
+    '> ESC P<ST>'        : 'DCS / device control string',
+    '> ESC Q'            : 'PU1 / private use one',
+    '> ESC R'            : 'PU2 / private use two',
+    '> ESC S'            : 'STS / set transmit state',
+    '> ESC T'            : 'CCH / cancel character',
+    '> ESC U'            : 'MW / message waiting',
+    '> ESC V'            : 'SPA / start of guarded area',
+    '> ESC W'            : 'EPA / end of guarded area',
+    '> ESC X<ST>'        : 'SOS / start of string',
+    '> ESC Z'            : 'SCI / single character introducer',
     '> ESC ]<ST>'        : 'OSC',
     '> ESC ^<ST>'        : 'PM',
     '> ESC _<ST>'        : 'APC',
-    '> ESC X<ST>'        : 'SOS',
     '> CSI @'            : 'ICH / insert blank characters',
     '> CSI [0]@'         : 'ICH 1 / insert a blank character',
     '> CSI A'            : 'CUU / cursor up',
     '> CSI [0]A'         : 'CUU 1 / cursor up',
+    '> CSI =A'           : 'SBC / set border color',
+    '> CSI =0A'          : 'SBC 0 / set border color to black',
+    '> CSI =1A'          : 'SBC 1 / set border color to blue',
+    '> CSI =2A'          : 'SBC 2 / set border color to green',
+    '> CSI =3A'          : 'SBC 3 / set border color to cyan',
+    '> CSI =4A'          : 'SBC 4 / set border color to red',
+    '> CSI =5A'          : 'SBC 5 / set border color to magenta',
+    '> CSI =6A'          : 'SBC 6 / set border color to brown',
+    '> CSI =7A'          : 'SBC 7 / set border color to white',
+    '> CSI =8A'          : 'SBC 8 / set border color to gray',
+    '> CSI =9A'          : 'SBC 9 / set border color to light blue',
+    '> CSI =10A'         : 'SBC 10 / set border color to light green',
+    '> CSI =11A'         : 'SBC 11 / set border color to light cyan',
+    '> CSI =12A'         : 'SBC 12 / set border color to light red',
+    '> CSI =13A'         : 'SBC 13 / set border color to light magenta',
+    '> CSI =14A'         : 'SBC 14 / set border color to yellow',
+    '> CSI =15A'         : 'SBC 15 / set border color to light white',
     '> CSI B'            : 'CUD / cursor down',
     '> CSI [0]B'         : 'CUD 1 / cursor down',
+    '> CSI =B'           : 'SBP / set bell parameters',
+    '> CSI =[2]B'        : 'SBP / set bell parameters - frequency=%d, duration=%d',
     '> CSI C'            : 'CUF / cursor forward',
     '> CSI [0]C'         : 'CUF 1 / cursor forward',
+    '> CSI =C'           : 'set cursor parameters',
     '> CSI D'            : 'CUB / cursor backward',
     '> CSI [0]D'         : 'CUB 1 / cursor backward',
+    '> CSI =D'           : 'SBI / set backward intensity',
     '> CSI E'            : 'CNL / cursor next line',
     '> CSI [0]E'         : 'CNL 1 / cursor next line',
     '> CSI F'            : 'CPL / cursor preceding line',
@@ -471,6 +500,10 @@ _SEQDB = {
     '> CSI 0K'           : 'EL 0 / erase line: from the cursor through the end of the line',
     '> CSI 1K'           : 'EL 1 / erase line: from the beginning of the line through the cursor',
     '> CSI 2K'           : 'EL 2 / erase line: the complete of line',
+    '> CSI ?K'           : 'DECSEL / selective erase: from the cursor through the end of line',
+    '> CSI ?0K'          : 'DECSEL 0 / selective erase: from the cursor through the end of line',
+    '> CSI ?1K'          : 'DECSEL 1 / selective erase: from the beginning of the line through the cursor',
+    '> CSI ?2K'          : 'DECSEL 2 / selective erase: the complete of line',
     '> CSI L'            : 'IL / insert lines',
     '> CSI [0]L'         : 'IL 1 / insert a line',
     '> CSI M'            : 'DL / delete lines',
@@ -808,6 +841,16 @@ _SEQDB = {
     '> CSI `~'           : 'DECDC / insert Ps Column(s)',
     '> CSI [0]`~'        : 'DECDC / insert a Column(s)',
     '> CSI [1]`~'        : 'DECDC / insert %s Column(s)',
+    '> CSI [0]]'         : 'ignore next character (linux console)',
+    '> CSI 1;[1]]'       : 'set color %d as the underline color (linux console)',
+    '> CSI 2;[1]]'       : 'set color %d as the dim color (linux console)',
+    '> CSI 8]'           : 'make the current color pair the default attributes (linux console)',
+    '> CSI 9;[1]]'       : 'set screen blank timeout to %d minutes (linux console)',
+    '> CSI 10;[1]]'      : 'set bell frequency with %d Hz (linux console)',
+    '> CSI 11;[1]]'      : 'set bell duration with %d msec (linux console)',
+    '> CSI 12;[1]]'      : 'bring %dth console to the front (linux console)',
+    '> CSI 13]'          : 'unblank the screen (linux console)',
+    '> CSI 14;[1]]'      : 'set the VESA powerdown interval with %d minutes (linux console)',
 }
 
 _DEFAULT_CONF = """
