@@ -18,18 +18,21 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 # ***** END LICENSE BLOCK *****
 
-import seqdb, controller
+import seqdb
+import controller
 
 _DB = seqdb.get()
 
+
 def get_mnemonic(direction, f):
     key = "%s ESC O %s" % (direction, f)
     if key in _DB:
         mnemonic = _DB[key]
-    else: 
+    else:
         mnemonic = '<Unknown>'
     return mnemonic
 
+
 def format(final, is_input, tracer, controller):
     f = chr(final)
 
@@ -38,7 +41,7 @@ def format(final, is_input, tracer, controller):
     else:
         direction = '>'
 
-    mnemonic = get_mnemonic(direction, f) 
+    mnemonic = get_mnemonic(direction, f)
     if mnemonic[0] == "!":
         eval(mnemonic[1:])
         return None
@@ -46,11 +49,11 @@ def format(final, is_input, tracer, controller):
     context = []
     if f:
         context.append("\x1b[33m" + f)
-    result = "\x1b[0;1;36;44m ESC O %s \x1b[0;1;31m\x0d\x1b[30C%s" % (" ".join(context), mnemonic)
+    template = "\x1b[0;1;36;44m ESC O %s \x1b[0;1;31m\x0d\x1b[30C%s"
+    result = template % (" ".join(context), mnemonic)
     return result
 
- 
-if __name__ == "__main__":
-   import doctest
-   doctest.testmod()
 
+if __name__ == "__main__":
+    import doctest
+    doctest.testmod()
